=======
History
=======

1.0.2 (2019-05-24)
------------------

* Removed view references from cyVisualProperties aspect of style.cx file cause it was causing issues with loading in cytoscape

* Set directed edge attribute type to boolean cause it was incorrectly defaulting to a string

1.0.1 (2019-05-18)
------------------

* Renamed incorrect attribute name prov:wasDerivedBy to prov:wasDerivedFrom
  to adhere to normalization document requirements
 
1.0.0 (2019-05-16)
------------------

* Massive refactoring and first release where code attempts to behave as defined in README.rst

0.1.1 (2019-02-15)
------------------

* Updated data/style.cx by renaming Protein to protein and SmallMolecule
  to smallmolecule to match the new normalization conventions


0.1.0 (2019-02-15)
------------------

* First release
